@@ -262,26 +262,33 @@ class SQLiteHandler(HandlerBase):
                 "utiliser plutôt l'attribut 'message'."
             )
         super().__init__(format = format)
+        self.kargs_sql = kargs_sql
+        self.path_sql = path_sql
         self.base_name = base_name
-        self.conn = sqlite3.connect(path_sql, **kargs_sql)
-        self.conn.execute(
+        conn = sqlite3.connect(path_sql, **kargs_sql)
+        conn.execute(
             f"CREATE TABLE IF NOT EXISTS {self.base_name}("
                 f"{', '.join([f'{cc} {MAP_TYPE_HANDLER[cc]}' for cc in self.format])}"
             ")"
         )
-        self.conn.commit()
+        conn.commit()
+        conn.close()
+        del conn
 
     def emit(self, record: logging.LogRecord):
         self._asctime(record)
         self._message(record)
         self._engine(record, 'sqlite')
         log_in = self._extract_format(record)
-        self.conn.execute(
+        conn = sqlite3.connect(self.path_sql, **self.kargs_sql)
+        conn.execute(
             f"INSERT INTO {self.base_name}({', '.join(self.format)}) "
             f"VALUES({', '.join(len(self.format)*'?')})",
             log_in
         )
-        self.conn.commit()
+        conn.commit()
+        conn.close()
+        del conn
 
 class SQLAlchemyHandler(HandlerBase):
     r"""
@@ -408,6 +415,7 @@ class SQLAlchemyHandler(HandlerBase):
                  base_name: str='logs',
                  **kargs_sql):
         try:
+            global sqlalchemy
             import sqlalchemy
             from sqlalchemy.types import Integer, Float, String
         except ModuleNotFoundError:
@@ -424,6 +432,8 @@ class SQLAlchemyHandler(HandlerBase):
                 "utiliser plutôt l'attribut 'message'."
             )
         super().__init__(format = format)
+        self.path_sql = path_sql
+        self.kargs_sql = kargs_sql
         self.base_name = base_name
         map_type = dict(
             TEXT = String(258),
@@ -431,23 +441,27 @@ class SQLAlchemyHandler(HandlerBase):
             REAL = Float()
         )
         engine = sqlalchemy.create_engine(path_sql, **kargs_sql)
-        self.conn = engine.connect()
-        self.conn.execute(
-            f"CREATE TABLE IF NOT EXISTS {self.base_name}("
-                f"{', '.join([f'{cc} {map_type[MAP_TYPE_HANDLER[cc]]}' for cc in self.format])}"
-            ")"
-        )
+        with engine.connect() as conn:
+            conn.execute(
+                f"CREATE TABLE IF NOT EXISTS {self.base_name}("
+                    f"{', '.join([f'{cc} {map_type[MAP_TYPE_HANDLER[cc]]}' for cc in self.format])}"
+                ")"
+            )
+        del engine
 
     def emit(self, record: logging.LogRecord):
         self._asctime(record)
         self._message(record)
         self._engine(record, 'sqlalchemy')
         log_in = self._extract_format(record)
-        self.conn.execute(
-            f"INSERT INTO {self.base_name}({', '.join(self.format)}) "
-            f"VALUES({', '.join(len(self.format)*'?')})",
-            log_in
-        )
+        engine = sqlalchemy.create_engine(self.path_sql, **self.kargs_sql)
+        with engine.connect() as conn:
+            conn.execute(
+                f"INSERT INTO {self.base_name}({', '.join(self.format)}) "
+                f"VALUES({', '.join(len(self.format)*'?')})",
+                log_in
+            )
+        del engine
 
 class BaseArtimon(HandlerBase):
     r"""
