@@ -9,6 +9,7 @@ Created on Mon Oct 21 14:42:57 2019
 """
 import uuid
 import pickle as pkl
+from types import FunctionType
 from typing import (Optional, ByteString, Union, Callable, Dict, Any, List,
                     Tuple)
 from collections import OrderedDict
@@ -706,7 +707,10 @@ class BaseEnvironnement(BaseEstimator):
             nb_epoch=nb_epoch,
             epoch_max_steps=len(dataset),
             eval_max_steps=len(eval_dataset) if eval_dataset else 0,
-            loss_name=loss_fn.__name__
+            loss_name=(
+                loss_fn.__name__ if isinstance(loss_fn, FunctionType)
+                else loss_fn.__class__.__name__
+            )
         )
         control = FitControl()
 
